@@ -1,8 +1,8 @@
 package Sys::Info::Driver::Linux;
-$Sys::Info::Driver::Linux::VERSION = '0.7905';
+$Sys::Info::Driver::Linux::VERSION = '0.7906';
 use strict;
 use warnings;
-use base qw( Exporter );
+use parent qw( Exporter );
 
 our @EXPORT = qw( proc );
 
@@ -33,7 +33,7 @@ Sys::Info::Driver::Linux
 
 =head1 VERSION
 
-version 0.7905
+version 0.7906
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ Automatically exported. Includes paths to several files.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
