@@ -1,8 +1,8 @@
 package Sys::Info::Driver::Linux::OS;
-$Sys::Info::Driver::Linux::OS::VERSION = '0.7904';
+$Sys::Info::Driver::Linux::OS::VERSION = '0.7906';
 use strict;
 use warnings;
-use base qw( Sys::Info::Base );
+use parent qw( Sys::Info::Base );
 use POSIX ();
 use Cwd;
 use Carp qw( croak );
@@ -267,7 +267,7 @@ Sys::Info::Driver::Linux::OS
 
 =head1 VERSION
 
-version 0.7904
+version 0.7906
 
 =head1 SYNOPSIS
 
@@ -325,7 +325,7 @@ L<http://www.redhat.com/docs/manuals/linux/RHL-9-Manual/ref-guide/s1-proc-topfil
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy
 
 =head1 COPYRIGHT AND LICENSE
 
